==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Select/SelectContour/ts/SelectContour_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>SelectContour</name>
    <message>
        <location filename="../SelectContour.js" line="+53"/>
        <source>Choose entity of contour</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wybierz jednostkę konturu</translation>
    </message>
    <message>
        <location filename="../SelectContour.ui" line="+17"/>
        <source>Mode:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Tryb:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zamień bieżące zaznaczenie</translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">SelectionMode</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Dodać do wyboru bieżących</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Odejmij od bieżącego zaznaczenia</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przecięcie z bieżącego zaznaczenia</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Tolerance:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Tolerancja:</translation>
    </message>
    <message>
        <location filename="../SelectContourInit.js" line="+2"/>
        <source>(De-)Select &amp;Contour</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
(Za/Od)znacz &amp;Kontur</translatorcomment>
        <translation type="unfinished">(Za/Od)znacz &amp;Kontur</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select connected entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">(De-) Wybierz jednostkami powiązanymi</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Select/SelectContour/ts/SelectContour_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SelectContour</name>
    <message>
        <location filename="../SelectContour.js" line="+53"/>
        <source>Choose entity of contour</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać obiekt konturu</translation>
    </message>
    <message>
        <location filename="../SelectContour.ui" line="+17"/>
        <source>Mode:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tryb:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Replace the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zamień aktualne zaznaczenie</translation>
    </message>
    <message>
        <location line="+16"/>
        <location line="+20"/>
        <location line="+20"/>
        <location line="+20"/>
        <source>SelectionMode</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>TrybZaznaczania</translation>
    </message>
    <message>
        <location line="-53"/>
        <source>Add to the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Dodaj do aktualnego zaznaczenia</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Subtract from the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odejmij od aktualnego zaznaczenia</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Intersect with the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyznacz część wspólną z aktualnym zaznaczeniem</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Tolerance:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tolerancja:</translation>
    </message>
    <message>
        <location filename="../SelectContourInit.js" line="+2"/>
        <source>(De-)Select &amp;Contour</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
(Za/Od)znacz &amp;Kontur</translatorcomment>
        <translation>Zaznacz &amp;kontur</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>(De-)Select connected entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zaznacza lub odznacza połączone obiekty</translation>
    </message>
</context>
</TS>
